package io.swagger.client.api;

import io.swagger.client.model.*;

import retrofit.http.*;
import retrofit.mime.*;
import java.util.*;


public interface DNSApi {
  
  /**
   * Создание записи домена
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param addDnsZone зона, которую необходимо создать
   * @param addDnsRecord 
   * @param iisSiteForDns ID сайта из /website/list, либо IP-адрес виртуального сервера, к которому необходимо сделать привязку
   * @param bindOnly 
   * @return String
   */
  
  @GET("/dns/add")  
  String dnsAddGet(
    @Query("_token_") String token_,@Query("add_dns_zone") String addDnsZone,@Query("add_dns_record") String addDnsRecord,@Query("iis_site_for_dns") String iisSiteForDns,@Query("bind_only") Boolean bindOnly
  );  
  
  /**
   * Привязка одного домена к другому
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID домена из списка /dns/list
   * @param bindTo домен, к которому необходимо сделать привязку
   * @return String
   */
  
  @GET("/dns/bind")  
  String dnsBindGet(
    @Query("_token_") String token_,@Query("_key_") Integer key_,@Query("bind_to") String bindTo
  );  
  
  /**
   * Получить список доменных имён
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/dns/list")  
  List<Object> dnsListGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Информация по продлению доменов
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/dns/prolong/list")  
  List<Object> dnsProlongListGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Редактирование \&quot;сырой\&quot; зоны
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID домена из /dns/list
   * @param sDel Значение &#39;1&#39; сообщает, что запись необходимо удалить
   * @param sAdd Значение &#39;1&#39; сообщает, что запись необходимо создать
   * @param dnsType Тип записи: A, MX, CNAME, AAAA, NS, TXT, SRV
   * @param dnsName Имя записи, либо &#39;@&#39; для корневой
   * @param dnsValue Содержание записи (для A это IP-адрес, для CNAME имя, для MX приоритет и назначение)
   * @return String
   */
  
  @GET("/dns/raw")  
  String dnsRawGet(
    @Query("_token_") String token_,@Query("_key_") Integer key_,@Query("s_del") Integer sDel,@Query("s_add") Integer sAdd,@Query("dns_type") String dnsType,@Query("dns_name") String dnsName,@Query("dns_value") String dnsValue
  );  
  
  /**
   * Редактировать DNS-зону
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID домена из /dns/list
   * @param managedMx Значение &#39;1&#39;, если необходимо включить поддержку на MX-серверах хостинга и &#39;0&#39;, если выключить
   * @param updManagedMx Значение &#39;1&#39; подтверждает операцию
   * @return String
   */
  
  @GET("/dns/raw/managedmx")  
  String dnsRawManagedmxGet(
    @Query("_token_") String token_,@Query("_key_") Integer key_,@Query("managed_mx") Integer managedMx,@Query("upd_managed_mx") Integer updManagedMx
  );  
  
}
