package io.swagger.client.api;

import io.swagger.client.model.*;

import retrofit.http.*;
import retrofit.mime.*;
import java.util.*;

import java.math.BigDecimal;

public interface DefaultApi {
  
  /**
   * Аккаунт: баланс
   * Возвращает текущий баланс аккаунта
   * @param token_ Ключ доступа, полученный при авторизации
   * @return BigDecimal
   */
  
  @GET("/balance")  
  BigDecimal balanceGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Аккаунт: баланс аккаунта лицензий
   * Возвращает текущий баланс аккаунта лицензий
   * @param token_ Ключ доступа, полученный при авторизации
   * @return BigDecimal
   */
  
  @GET("/balance.lic")  
  BigDecimal balanceLicGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Информация по дебету аккаунта
   * Данный запрос позволяет получить информацию по планируемым датам наступления негативного баланса и отключения
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/billing/debt")  
  List<Object> billingDebtGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Информация об аккаунте
   * Этот запрос позволяет получить информацию об аккаунте, а также базовую статистику использования ресурсов.
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/billing/info")  
  List<Object> billingInfoGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Получить ограничения аккаунта
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @return Object
   */
  
  @GET("/billing/limits")  
  Object billingLimitsGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Информация по продлению доменов
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/dns/prolong/list")  
  List<Object> dnsProlongListGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Создание почтового ящика
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param addEmail Адрес почтового ящика, который необходимо создать
   * @return String
   */
  
  @GET("/email/add")  
  String emailAddGet(
    @Query("_token_") String token_,@Query("add_email") String addEmail
  );  
  
  /**
   * Удаление псевдонимов почтовых ящиков
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ Адрес почтового ящика, подлежащего удалению
   * @return String
   */
  
  @GET("/email/alias/delete")  
  String emailAliasDeleteGet(
    @Query("_token_") String token_,@Query("_key_") String key_
  );  
  
  /**
   * Получить список псевдонимов почтовых ящиков
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/email/alias/list")  
  List<Object> emailAliasListGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Удаление почтового ящика
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ Адрес почтового ящика, подлежащего удалению
   * @return String
   */
  
  @GET("/email/delete")  
  String emailDeleteGet(
    @Query("_token_") String token_,@Query("_key_") String key_
  );  
  
  /**
   * Получить список почтовых ящиков
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/email/list")  
  List<Object> emailListGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Идентификатор последнего уведомления в аудите
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @return Integer
   */
  
  @GET("/updates/last")  
  Integer updatesLastGet(
    @Query("_token_") String token_
  );  
  
  /**
   * Список записей аудита
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID первой записи для показа или 0 для показа всех записей
   * @return List<Object>
   */
  
  @GET("/updates/list")  
  List<Object> updatesListGet(
    @Query("_token_") String token_,@Query("_key_") Integer key_
  );  
  
  /**
   * Удаление сайта
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID сайта, полученный из /website/list
   * @return String
   */
  
  @GET("/website/delete")  
  String websiteDeleteGet(
    @Query("_token_") String token_,@Query("_key_") String key_
  );  
  
  /**
   * Список сайтов аккаунта
   * 
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/website/list")  
  List<Object> websiteListGet(
    @Query("_token_") String token_
  );  
  
}
