package io.swagger.client.api;

import io.swagger.client.model.*;

import retrofit.http.*;
import retrofit.mime.*;
import java.util.*;


public interface VDSHyperVOpenVZApi {
  
  /**
   * Создание VDS
   * Создание новых VDS с произвольными характеристиками
   * @param token_ Ключ доступа, полученный при авторизации
   * @param type Тип создаваемого VDS. &#39;vz1&#39;, &#39;vz2&#39;, &#39;vz3&#39;, &#39;vz4&#39;, &#39;vz5&#39; или &#39;vds.dynamic&#39;. По умолчанию &#39;vds.dynamic&#39;
   * @param crHvmem Количество доступной памяти в мегабайтах. По умолчанию 2048
   * @param crHvdsk Количество доступных гигабайт диска. По умолчанию 30
   * @param crHvcpu Количество ядер CPU. По умолчанию 2
   * @param template Шаблон и тип виртуализации VDS. За подробностями см. /vds/templates-list
   * @param forceMemo 
   * @param hv1gbPanelVersion 
   * @param panelInstall Необходимо ли установить панель 1Gb на VDS
   * @return String
   */
  
  @GET("/vds/create")  
  String vdsCreateGet(
    @Query("_token_") String token_,@Query("type") String type,@Query("cr_hvmem") Integer crHvmem,@Query("cr_hvdsk") Integer crHvdsk,@Query("cr_hvcpu") Integer crHvcpu,@Query("template") String template,@Query("force_memo") String forceMemo,@Query("hv_1gb_panel_version") String hv1gbPanelVersion,@Query("panel_install") Boolean panelInstall
  );  
  
  /**
   * Удаление VDS
   * Предоставляет функционал для удаления VDS
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID виртуального сервера, полученный из /vds/list
   * @param forceCritical Если true, VDS будет удален срочно
   * @return String
   */
  
  @GET("/vds/delete")  
  String vdsDeleteGet(
    @Query("_token_") String token_,@Query("_key_") Integer key_,@Query("force_critical") Boolean forceCritical
  );  
  
  /**
   * Список IP-адресов виртуальных серверов
   * Список IP-адресов виртуальных серверов
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID виртуального сервера, полученный из /vds/list
   * @return List<Object>
   */
  
  @GET("/vds/ip/list")  
  List<Object> vdsIpListGet(
    @Query("_token_") String token_,@Query("_key_") Integer key_
  );  
  
  /**
   * Список виртуальных серверов
   * Позволяет получить список виртуальных серверов
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID виртуального сервера. Если задан, то будет выдана информация только для этого VDS
   * @return List<Object>
   */
  
  @GET("/vds/list")  
  List<Object> vdsListGet(
    @Query("_token_") String token_,@Query("_key_") Integer key_
  );  
  
  /**
   * Перезагрузка VDS
   * Предоставляет функционал для перезагрузки VDS
   * @param token_ Ключ доступа, полученный при авторизации
   * @param key_ ID виртуального сервера, полученный из /vds/list
   * @return String
   */
  
  @GET("/vds/reboot")  
  String vdsRebootGet(
    @Query("_token_") String token_,@Query("_key_") Integer key_
  );  
  
  /**
   * Список шаблонов виртуальных серверов
   * Позволяет получить список шаблонов виртуальных серверов
   * @param token_ Ключ доступа, полученный при авторизации
   * @return List<Object>
   */
  
  @GET("/vds/templates-list")  
  List<Object> vdsTemplatesListGet(
    @Query("_token_") String token_
  );  
  
}
